Module constants

Module constants 

Common constants and identifiers used across the Simplex SDK.

Constants

DUMMY_SIGNATURE
Dummy signature, which is used for fee estimation
LIQUID_DEFAULT_REGTEST_ASSET_STR
Policy AssetId (hex, BE) for Elements regtest.
LIQUID_POLICY_ASSET_STR
Policy AssetId (hex, BE) for Liquid mainnet.
LIQUID_TESTNET_POLICY_ASSET_STR
Policy AssetId (hex, BE) for Liquid testnet.
LIQUID_TESTNET_TEST_ASSET_ID_STR
Example test AssetId (hex, BE) on Liquid testnet.
MIN_FEE
Minimal acceptable fee for nodes to send a transaction
PUBLIC_SECRET_BLINDER_KEY
General public blinder key to use