Global state, configuration, and shared context used throughout the SDK.
Structs
- Global
Config - A structure to represent the global configuration settings for the application.
Functions
- get_
log_ level - Returns the default log level if
GLOBAL_CONFIGis not initialized - set_
global_ config - Sets the global configuration for the SDK.