Program

Struct Program 

pub struct Program { /* private fields */ }
Represents a program structure containing its source, a public key, arguments, and associated storage.

Abstraction giving the power to execute Simplicity contracts without specifying any additional parameters.

Implementations

Source

impl Program

pub fn new(source: &'static str, arguments: Box<dyn ArgumentsTrait>) -> Program

Creates a new instance of the struct with the provided source string and arguments.

pub fn with_taproot_pubkey(self, pub_key: XOnlyPublicKey) -> Program

Sets the pub_key field of the struct to the provided XOnlyPublicKey value and returns the updated builder instance. This is used to set the taproot public key for the program.

pub fn with_storage_capacity(self, capacity: usize) -> Program

Sets storage capacity for further usage.

pub fn set_storage_at(&mut self, index: usize, new_value: [u8; 32])

Sets a 32-byte value at the specified index in the storage.

Panics

Panics if the index is out of bounds for the initiasized storage.

pub fn get_storage_len(&self) -> usize

Returns the number of storage chunks for a program.

pub fn get_storage(&self) -> &[[u8; 32]]

Returns storage as a whole array of 32-byte chunks.

pub fn get_storage_at(&self, index: usize) -> [u8; 32]

Returns storage value at a certain index.

Panics

Panics if the index is out of bounds for the initiated storage.

pub fn get_tr_address(&self, network: &SimplicityNetwork) -> Address

Returns a taproot address for a defined SimplicityNetwork.

Panics

Panics if generating the taproot spending information fails.

pub fn get_script_pubkey(&self, network: &SimplicityNetwork) -> Script

Retrieves the ScriptPubKey associated with the Simplicity address for the specified network.

pub fn get_script_hash(&self, network: &SimplicityNetwork) -> [u8; 32]

Retrieves the 32-byte ScriptPubKey hash associated with the Simplicity address for the specified network.

pub fn get_argument_types(&self) -> Result<Parameters, ProgramError>

Retrieves program ABI metadata for argument types.

Errors

Returns a ProgramError if compilation fails or generating ABI metadata fails.

pub fn get_witness_types(&self) -> Result<WitnessTypes, ProgramError>

Retrieves the witness types from the compiled program’s ABI metadata.

Errors

Returns a ProgramError if compilation fails or generating ABI metadata fails.