ArgumentsTrait

Trait ArgumentsTrait 

pub trait ArgumentsTrait: DynClone {
    // Required method
    fn build_arguments(&self) -> Arguments;
}
An interface for structs capable of generating static argument mapping for Simplicity programs. See the include_simc!() macro, which generates automatic ArgumentsTrait implementation.

Required Methods

fn build_arguments(&self) -> Arguments

Compiles and returns the bound Arguments dict required to instantiate a program.

Implementors