pub enum ProviderError {
Rpc(RpcError),
Request(String),
Confirmation(),
BroadcastRejected {
status: u16,
url: String,
message: String,
},
Deserialize(String),
InvalidTxid(String),
}Expand description
Defines standard errors possible when using a blockchain interaction provider.
Variants
Rpc(RpcError)
Wrapper around an RPC-level error representing transport or network-level connectivity failures to the inner node.
Request(String)
Error indicating that a standard HTTP request to a provider (such as an Esplora REST instance) encountered a failure.
Confirmation()
Error indicating the configured timeout to wait for transaction confirmation elapsed without confirmation.
BroadcastRejected
Error indicating a provider returned a non-success response explicitly rejecting a broadcasted transaction payload.
Fields
Deserialize(String)
Error indicating that a provider’s raw response body was unable to be correctly deserialized into native structs or types.
InvalidTxid(String)
Error indicating an incorrectly formatted transaction ID string was encountered.