Module error

Module error 

Provider-specific error enumerations for handling transmission, retrieval, or interpretation issues.

Enums

ProviderError
Defines standard errors possible when using a blockchain interaction provider.