A lightweight JSON-RPC client wrapper and utility methods for interacting with an Elements node.
Structs
- Elements
Rpc - A lightweight wrapper around the standard
bitcoincore_rpcClientproviding Elements-specific functionality.
A lightweight JSON-RPC client wrapper and utility methods for interacting with an Elements node.
bitcoincore_rpc Client providing Elements-specific functionality.