ElementsRpc

Struct ElementsRpc 

pub struct ElementsRpc {
    pub inner: Client,
    pub auth: Auth,
    pub url: String,
}
A lightweight wrapper around the standard bitcoincore_rpc Client providing Elements-specific functionality.

Fields

inner: Client

The underlying JSON-RPC client connected to the Elements node.

auth: Auth

The authentication credentials used.

url: String

The URL endpoint of the node.

Implementations

Source

impl ElementsRpc

pub fn new(url: String, auth: Auth) -> Result<ElementsRpc, RpcError>

Creates a new ElementsRpc client.

Errors

Returns an RpcError if it fails to initialize the connection or if a liveness ping fails.

pub fn get_new_address(&self, label: &str) -> Result<Address, RpcError>

Requests a new wallet address from the node, mapped to the provided label.

Errors

Returns an RpcError if the node fails to generate an address or yields an invalid string payload.

Panics

Panics if the returned JSON value is not a string, or if the string cannot be parsed into a valid Address.

pub fn send_to_address( &self, address: &Address, satoshi: u64, asset: Option<AssetId>, ) -> Result<Txid, RpcError>

Instructs the node to transfer funds directly to the target address.

Errors

Returns an RpcError if the node returns an error or returns an invalid Txid payload.

Panics

Panics if the satoshi amount cannot be converted to a valid BTC amount, if the returned JSON value is not a string, or if the string cannot be parsed into a valid Txid.

pub fn rescan_blockchain( &self, start: Option<u64>, stop: Option<u64>, ) -> Result<(), RpcError>

Instructs the node to rescan the block chain for missed wallet transactions.

Errors

Returns an RpcError if the node fails the RPC call.

pub fn generate_blocks(&self, block_num: u64) -> Result<(), RpcError>

Mines a specified number of new blocks mapping generated rewards to a newly generated wallet address.

Errors

Returns an RpcError if generating the address or calling the generatetoaddress RPC command fails.

pub fn sweep_initialfreecoins(&self) -> Result<(), RpcError>

Instructs the node to sweep the initialfreecoins balance generated by standard regtest genesis blocks.

Errors

Returns an RpcError if the getnewaddress or sendtoaddress RPC commands fail.

pub fn height(&self) -> Result<u64, RpcError>

Retrieves the current block chain tip height.

Errors

Returns an RpcError if the node call fails or yields a JSON structure that does not map successfully to a u64.