pub struct EsploraProvider {
pub esplora_url: String,
pub network: SimplicityNetwork,
pub timeout: Duration,
}Expand description
A provider implementation that interacts with the Esplora REST API backend.
Fields
esplora_url: StringThe base URL of the Esplora REST API.
network: SimplicityNetworkThe currently configured Simplicity network (e.g. Liquid, Testnet, Regtest).
timeout: DurationTimeout duration used in underlying HTTP requests.
Implementations
Sourceimpl EsploraProvider
impl EsploraProvider
Sourcepub fn new(url: String, network: SimplicityNetwork) -> EsploraProvider
pub fn new(url: String, network: SimplicityNetwork) -> EsploraProvider
Creates a new EsploraProvider connected to the provided endpoint targeting the specific network.