SignerError

Enum SignerError 

pub enum SignerError {
Show 19 variants Program(ProgramError), Provider(ProviderError), WtnsInjectError(WtnsWrappingError), Mnemonic(String), TxExtraction(Error), Unblind(UnblindError), PsetBlind(PsetBlindError), SighashConstruction(SighashError), DustAmount(i64), NotEnoughFeeAmount(i64, u64), NotEnoughFunds(u64), InvalidSecretKey(Error), PrivateKeyDerivation(Error), DerivationPath(String), WpkhDescriptor(String), Slip77Descriptor(String), DescriptorConversion(ConversionError), WpkhAddressConstruction(Error), WtnsFieldNotFound(String),
}
Core error types for the Signer component.

Variants



Program(ProgramError)

Errors originating from Simplicity program evaluation and state.



Provider(ProviderError)

Errors originating from provider network interactions.



WtnsInjectError(WtnsWrappingError)

Errors encountered when attempting to inject or wrap witness fields.



Mnemonic(String)

Error indicating an incorrectly formatted mnemonic phrase.



TxExtraction(Error)

Error thrown when PSET transaction extraction fails.



Unblind(UnblindError)

Error indicating failure to unblind a confidential transaction output.



PsetBlind(PsetBlindError)

Error thrown when PSET blinding fails.



SighashConstruction(SighashError)

Error indicating failure to construct sighash for input spending.



DustAmount(i64)

Error indicating the transaction inputs cover an amount that is lower than the dust limit.



NotEnoughFeeAmount(i64, u64)

Error indicating the defined fee amount cannot cover the calculated transaction costs.



NotEnoughFunds(u64)

Error indicating that the available UTXO funds are not enough to cover total costs.



InvalidSecretKey(Error)

Error indicating an invalid upstream secp256k1 secret key.



PrivateKeyDerivation(Error)

Error thrown when HD wallet private key derivation fails.



DerivationPath(String)

Error thrown when constructing a derivation path string fails.



WpkhDescriptor(String)

Error indicating failure to construct a valid WPKH (Witness Public Key Hash) descriptor.



Slip77Descriptor(String)

Error indicating failure to construct a valid SLIP77 blinding key descriptor.



DescriptorConversion(ConversionError)

Error thrown if there’s a problem during descriptor conversion.



WpkhAddressConstruction(Error)

Error thrown when WPKH address creation fails.



WtnsFieldNotFound(String)

Error indicating an expected witness field could not be found.