pub enum WtnsWrappingError {
ParsingError,
UnsupportedPathType(String),
IdxOutOfBounds(usize, usize),
RootTypeMismatch(String, String),
EitherBranchMismatch,
}Expand description
Errors originating from manipulating witness paths and injecting values.
Variants
ParsingError
Error indicating a failure while parsing the provided witness path string.
UnsupportedPathType(String)
Error pointing to the use of a path type that is currently not supported.
IdxOutOfBounds(usize, usize)
Error thrown during path traversal when an index exceeds the inner array lengths.
RootTypeMismatch(String, String)
Error indicating that the runtime type at the path root expected one type but encountered another.
EitherBranchMismatch
Error indicating that a path traversal attempted to reach an undefined or mismatched Either branch.