pub enum RequiredSignature {
None,
NativeEcdsa,
Witness(String),
WitnessWithPath(String, Vec<String>),
}Expand description
Defines the type of signature required for an input.
Variants
None
No signature is required.
NativeEcdsa
A standard Native ECDSA (WPKH) signature is required.
Witness(String)
A generic witness payload associated with an external name.
WitnessWithPath(String, Vec<String>)
A witness payload requiring traversal through a specified path hierarchy.
Implementations
Sourceimpl RequiredSignature
impl RequiredSignature
Sourcepub fn witness_with_path<I>(name: &str, path: I) -> RequiredSignature
pub fn witness_with_path<I>(name: &str, path: I) -> RequiredSignature
Creates a WitnessWithPath requirement using an iterator of path segments.