pub struct UTXO {
pub outpoint: OutPoint,
pub txout: TxOut,
pub secrets: Option<TxOutSecrets>,
}Expand description
Represents an Unspent Transaction Output (UTXO).
Fields
outpoint: OutPointBounded outpoint for this object
txout: TxOutTransaction output characteristics
secrets: Option<TxOutSecrets>Already unblinded transaction output secrets
Implementations
Sourceimpl UTXO
impl UTXO
Sourcepub fn explicit_asset(&self) -> AssetId
pub fn explicit_asset(&self) -> AssetId
Retrieves the explicit AssetId from the transaction output (txout).
Panics
This function will panic if the UTXO’s asset is confidential.
Sourcepub fn explicit_amount(&self) -> u64
pub fn explicit_amount(&self) -> u64
Retrieves the explicit amount contained within the transaction output (UTXO).
Panics
This function will panic if the UTXO’s amount is confidential.
Sourcepub fn unblinded_asset(&self) -> AssetId
pub fn unblinded_asset(&self) -> AssetId
Retrieves the unblinded AssetId of the current UTXO.
Panics
This function will panic if the UTXO is not blinded. The panic occurs when
self.secrets is None, as it expects the UTXO to be in an unblinded state to retrieve the AssetId.
Sourcepub fn unblinded_amount(&self) -> u64
pub fn unblinded_amount(&self) -> u64
Retrieves the unblinded amount from the UTXO.
Panics
This function will panic if the UTXO is not confidential.