Module tx_receipt

Module tx_receipt 

Contains data representing the submission status of a broadcast transaction.

Structs

TxReceipt
A receipt for a broadcast transaction, containing the provider context and the transaction ID.