tr_unspendable_key

Function tr_unspendable_key 

pub fn tr_unspendable_key() -> XOnlyPublicKey
Generates a hardcoded “unspendable” Taproot public key.

Panics

Panics if the hardcoded byte slice is not exactly 32 bytes or cannot be parsed into a valid XOnlyPublicKey (which should never happen statically).