Module global

Module global 

Global state, configuration, and shared context used throughout the SDK.

Structs

GlobalConfig
A structure to represent the global configuration settings for the application.

Functions

get_log_level
Returns the default log level if GLOBAL_CONFIG is not initialized
set_global_config
Sets the global configuration for the SDK.