pub fn set_global_config(log_level: TrackerLogLevel) -> Result<(), GlobalConfig>Expand description
Sets the global configuration for the SDK.
This function allows setting a global configuration which includes
the logging level for simplicity contracts execution.
It must be called exactly once during the application’s lifetime.
Errors
Returns an error containing the newly created GlobalConfig if the global configuration has already been initialized.