Constructs and builders for assembling, tracking, and managing Elements transactions.
Modules
- final_
transaction - Represents a fully finalized target transaction schema ready for signing and broadcasting.
- partial_
input - Represents inputs under construction before transaction finalization.
- partial_
output - Represents outputs under construction before transaction finalization.
- tx_
receipt - Contains data representing the submission status of a broadcast transaction.
- utxo
- Common representation of unspent transaction outputs used as funding sources.
Structs
- Final
Input - Represents the final input structure put into a
FinalTransactionfor processing. - Final
Transaction - A struct representing a final (but not yet signed) transaction.
- Issuance
Details - A structure representing the details of token issuance and related metadata.
- Partial
Input - Represents partially prepared input data for Elements transactions.
- Partial
Output - Represents partially prepared output data for Elements transactions.
- Program
Input - Represents an input that runs a specific Simplicity program with an associated witness.
- TxReceipt
- A receipt for a broadcast transaction, containing the provider context and the transaction ID.
- UTXO
- Represents an Unspent Transaction Output (UTXO).
Enums
- Required
Signature - Defines the type of signature required for an input.