Module tx_receipt
simplex
0.0.5
Module tx_
receipt
Module Items
Structs
In simplex::
transaction
simplex
::
transaction
Module
tx_
receipt
Contains data representing the submission status of a broadcast transaction.
Structs

TxReceipt
A receipt for a broadcast transaction, containing the provider context and the transaction ID.